==> jc-1.4.0.tar.gz: soot/util/dot/DotGraphUtility.h <==
// public class soot.util.dot.DotGraphUtility

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class af4bddab63ed936d soot_util_dot_DotGraphUtility

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_dot_DotGraphUtility_H_
#define _JC_soot_util_dot_DotGraphUtility_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_util_dot_DotGraphUtility$sub_refs	_jc_soot_util_dot_DotGraphUtility$sub_refs;
typedef struct _jc_soot_util_dot_DotGraphUtility$sub_nonrefs	_jc_soot_util_dot_DotGraphUtility$sub_nonrefs;
typedef struct _jc_soot_util_dot_DotGraphUtility$refs	_jc_soot_util_dot_DotGraphUtility$refs;
typedef struct _jc_soot_util_dot_DotGraphUtility$nonrefs	_jc_soot_util_dot_DotGraphUtility$nonrefs;
typedef struct _jc_soot_util_dot_DotGraphUtility$object	_jc_soot_util_dot_DotGraphUtility$object;

typedef const struct _jc_soot_util_dot_DotGraphUtility$vmethods	_jc_soot_util_dot_DotGraphUtility$vmethods;
typedef const struct _jc_soot_util_dot_DotGraphUtility$vtable	_jc_soot_util_dot_DotGraphUtility$vtable;
typedef const struct _jc_soot_util_dot_DotGraphUtility$vtype	_jc_soot_util_dot_DotGraphUtility$vtype;

// Constructors
extern void _jc_soot_util_dot_DotGraphUtility$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_util_dot_DotGraphUtility$object *);

// Static methods
extern void _jc_soot_util_dot_DotGraphUtility$method$renderLine$f3c01a089c05d803(_jc_env *, struct _jc_java_io_OutputStream$object *, struct _jc_java_lang_String$object *, jint);
extern struct _jc_java_lang_String$object *_jc_soot_util_dot_DotGraphUtility$method$replaceQuotes$5bc55a16219742c1(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_soot_util_dot_DotGraphUtility$method$replaceReturns$aa928e5c8e2e45c0(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_soot_util_dot_DotGraphUtility$vmethods {
};

// Vtable
struct _jc_soot_util_dot_DotGraphUtility$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_dot_DotGraphUtility$vmethods	soot_util_dot_DotGraphUtility;
};

// Vtype
struct _jc_soot_util_dot_DotGraphUtility$vtype {
	_jc_type			type;
	_jc_soot_util_dot_DotGraphUtility$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_dot_DotGraphUtility$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_util_dot_DotGraphUtility$refs {
    _jc_soot_util_dot_DotGraphUtility$sub_refs	soot_util_dot_DotGraphUtility;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_dot_DotGraphUtility$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_dot_DotGraphUtility$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_dot_DotGraphUtility$sub_nonrefs	soot_util_dot_DotGraphUtility;
};

// Object instance structure
struct _jc_soot_util_dot_DotGraphUtility$object {
	_jc_soot_util_dot_DotGraphUtility$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_dot_DotGraphUtility$vtype	*vtype;
	_jc_soot_util_dot_DotGraphUtility$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_dot_DotGraphUtility$vtype _jc_soot_util_dot_DotGraphUtility$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_dot_DotGraphUtility, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_dot_DotGraphUtility$class_object;

#endif	/* _JC_soot_util_dot_DotGraphUtility_H_ */

==> jc-1.4.6.tar.gz: soot/util/dot/DotGraphUtility.h <==
// public class soot.util.dot.DotGraphUtility

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class af4bddab63ed936d soot_util_dot_DotGraphUtility

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_dot_DotGraphUtility_H_
#define _JC_soot_util_dot_DotGraphUtility_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_util_dot_DotGraphUtility$sub_refs	_jc_soot_util_dot_DotGraphUtility$sub_refs;
typedef struct _jc_soot_util_dot_DotGraphUtility$sub_nonrefs	_jc_soot_util_dot_DotGraphUtility$sub_nonrefs;
typedef struct _jc_soot_util_dot_DotGraphUtility$refs	_jc_soot_util_dot_DotGraphUtility$refs;
typedef struct _jc_soot_util_dot_DotGraphUtility$nonrefs	_jc_soot_util_dot_DotGraphUtility$nonrefs;
typedef struct _jc_soot_util_dot_DotGraphUtility$object	_jc_soot_util_dot_DotGraphUtility$object;

typedef const struct _jc_soot_util_dot_DotGraphUtility$vmethods	_jc_soot_util_dot_DotGraphUtility$vmethods;
typedef const struct _jc_soot_util_dot_DotGraphUtility$vtable	_jc_soot_util_dot_DotGraphUtility$vtable;
typedef const struct _jc_soot_util_dot_DotGraphUtility$vtype	_jc_soot_util_dot_DotGraphUtility$vtype;

// Constructors
extern void _jc_soot_util_dot_DotGraphUtility$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_util_dot_DotGraphUtility$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_soot_util_dot_DotGraphUtility$method$renderLine$f3c01a089c05d803(_jc_env *, struct _jc_java_io_OutputStream$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_util_dot_DotGraphUtility$method$replaceQuotes$5bc55a16219742c1(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_util_dot_DotGraphUtility$method$replaceReturns$aa928e5c8e2e45c0(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_util_dot_DotGraphUtility$vmethods {
};

// Vtable
struct _jc_soot_util_dot_DotGraphUtility$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_dot_DotGraphUtility$vmethods	soot_util_dot_DotGraphUtility;
};

// Vtype
struct _jc_soot_util_dot_DotGraphUtility$vtype {
	_jc_type			type;
	_jc_soot_util_dot_DotGraphUtility$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_dot_DotGraphUtility$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_util_dot_DotGraphUtility$refs {
    _jc_soot_util_dot_DotGraphUtility$sub_refs	soot_util_dot_DotGraphUtility;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_dot_DotGraphUtility$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_dot_DotGraphUtility$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_dot_DotGraphUtility$sub_nonrefs	soot_util_dot_DotGraphUtility;
};

// Object instance structure
struct _jc_soot_util_dot_DotGraphUtility$object {
	_jc_soot_util_dot_DotGraphUtility$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_dot_DotGraphUtility$vtype	*vtype;
	_jc_soot_util_dot_DotGraphUtility$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_dot_DotGraphUtility$vtype _jc_soot_util_dot_DotGraphUtility$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_dot_DotGraphUtility, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_dot_DotGraphUtility$class_object;

#endif	/* _JC_soot_util_dot_DotGraphUtility_H_ */
